==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "File could not be loaded. Please check your internet connection." : "Tiedostoa ei voitu ladata. Tarkista internetyhteytesi tila.",
    "Retry" : "Yritä uudelleen",
    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkyvät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert image" : "Lisää kuva",
    "Insert an image" : "Lisää kuva",
    "Link file" : "Linkitä tiedosto",
    "Select file to link to" : "Valitse tiedosto johon linkitetään",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "New text document" : "Uusi tekstiasiakirja",
    "Edit" : "Muokkaa",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Bold" : "Lihavoitu",
    "Italic" : "Kursivoitu",
    "Strikethrough" : "Yliviivattu",
    "Headings" : "Otsikot",
    "Heading 1" : "Otsikko 1",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Heading 6" : "Otsikko 6",
    "Unordered list" : "Järjestämätön lista",
    "Ordered list" : "Järjestetty lista",
    "Blockquote" : "Lohkolainaus",
    "Code block" : "Koodilohko",
    "Last save {lastSave}" : "Viimeisin tallennus {lastSave}",
    "Add link" : "Lisää linkki",
    "Show image" : "Näytä kuva",
    "Show file" : "Näytä tiedosto",
    "Paragraph" : "Kappale"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "Tekstiasiakirja",
    "Readme" : "Lueminut",
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "File could not be loaded. Please check your internet connection." : "Tiedostoa ei voitu ladata. Tarkista internetyhteytesi tila.",
    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkyvät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert image" : "Lisää kuva",
    "Insert an image" : "Lisää kuva",
    "Link file" : "Linkitä tiedosto",
    "Select file to link to" : "Valitse tiedosto johon linkitetään",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä...",
    "New text document" : "Uusi tekstiasiakirja",
    "Edit" : "Muokkaa",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Bold" : "Lihavoitu",
    "Italic" : "Kursivoitu",
    "Strikethrough" : "Yliviivattu",
    "Headings" : "Otsikot",
    "Heading 1" : "Otsikko 1",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Heading 6" : "Otsikko 6",
    "Unordered list" : "Lista",
    "Ordered list" : "Numeroitu lista",
    "ToDo list" : "Tehtävälista",
    "Blockquote" : "Lohkolainaus",
    "Code block" : "Koodilohko",
    "Retry" : "Yritä uudelleen",
    "Last save {lastSave}" : "Viimeisin tallennus {lastSave}",
    "Add link" : "Lisää linkki",
    "Show image" : "Näytä kuva",
    "Show file" : "Näytä tiedosto",
    "Paragraph" : "Kappale"
},
"nplurals=2; plural=(n != 1);");
